@@ -7,6 +7,7 @@ Created on 12 Sep 2020
 
 @author: semuadmin
 """
+# pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
 
 from tkinter import Frame, Text, Scrollbar, S, E, W, END, HORIZONTAL, VERTICAL, N
 
@@ -22,7 +23,7 @@ class ConsoleFrame(Frame):
         """
         Constructor.
 
-        :param app: reference to main tkinter application
+        :param object app: reference to main tkinter application
         """
 
         self.__app = app  # Reference to main application class
@@ -30,6 +31,7 @@ class ConsoleFrame(Frame):
 
         Frame.__init__(self, self.__master, *args, **kwargs)
 
+        self.width, self.height = self.get_size()
         self._body()
         self._do_layout()
         self._attach_events()
@@ -84,6 +86,8 @@ class ConsoleFrame(Frame):
 
         'maxlines' defines the maximum number of scrollable lines that are
         retained in the text box on a FIFO basis.
+
+        :param str data
         """
 
         settings = self.__app.frm_settings.get_settings()
@@ -107,6 +111,9 @@ class ConsoleFrame(Frame):
         """
         Highlights any occurrence of tags in line - each tag
         must be a tuple of (search term, highlight color)
+
+        :param str line
+        :param tuple tags: (search term, highlight color)
         """
 
         con = self.txt_console
@@ -122,9 +129,11 @@ class ConsoleFrame(Frame):
                 con.tag_add(count, f"{last}.{connect}", f"{last}.{end}")
                 con.tag_config(count, foreground=color)
 
-    def _on_resize(self, event):
+    def _on_resize(self, event):  # pylint: disable=unused-argument
         """
         Resize frame
+
+        :param event
         """
 
         self.width, self.height = self.get_size()
